
TODO: TODO_86_57_50_38: config-only for common delegator behavior

For example, if delegator cannot work with non-signled-out `data_envelop` and needs to fail with proper error
(rather than exception), provide configuration for such behaviors.

This makes some of the behavior of FS_49_96_50_77 config-only plugins available for any plugins.

